@@ -1,10 +1,11 @@
 ## File Name: DescribeBy.R
-## File Version: 9.03
+## File Version: 9.041
 
 
 #####################################################
 # S3 method DescribeBy
-DescribeBy <- function (object, ...) {
-    UseMethod("DescribeBy")
+DescribeBy <- function (object, ...)
+{
+    UseMethod('DescribeBy')
 }
 #####################################################
