@@ -1,5 +1,5 @@
 ## File Name: anova.tam.R
-## File Version: 9.12
+## File Version: 9.133
 
 
 #-- Likelihood ratio test for tam objects
@@ -8,7 +8,7 @@ anova.tam <- function( object, ... )
 {
     cl2 <- paste(match.call())[-1]
     if (length(list(object, ...)) !=2){
-        stop("anova method can only be applied for comparison of two models.\n")
+        stop('anova method can only be applied for comparison of two models.\n')
     }
     objects <- list(object, ...)
     model1 <- objects[[1]]
@@ -24,15 +24,14 @@ anova.tam <- function( object, ... )
     model2$loglike <- model2$deviance / (-2)
     model2$Npars <- model2$ic$Npars
     # test
-    dfr1 <- data.frame( "Model"=cl2[1],
-        "loglike"=model1$loglike,
-        "Deviance"=-2*model1$loglike )
+    dfr1 <- data.frame( Model=cl2[1], loglike=model1$loglike,
+                            Deviance=-2*model1$loglike )
     dfr1$Npars <- sum(model1$Npars)
     dfr1$AIC <- model1$AIC
     dfr1$BIC <- model1$BIC
-    dfr2 <- data.frame( "Model"=cl2[2],
-        "loglike"=model2$loglike,
-        "Deviance"=-2*model2$loglike )
+    dfr2 <- data.frame( 'Model'=cl2[2],
+        'loglike'=model2$loglike,
+        'Deviance'=-2*model2$loglike )
     dfr2$Npars <- sum(model2$Npars)
     dfr2$AIC <- model2$AIC
     dfr2$BIC <- model2$BIC
@@ -42,9 +41,9 @@ anova.tam <- function( object, ... )
     dfr$df <- NA
     dfr$p <- NA
     digits <- 5
-    dfr[1,"Chisq"] <- dfr[1,"Deviance"] - dfr[2,"Deviance"]
-    dfr[1,"df"] <- abs( dfr[1,"Npars"] - dfr[2,"Npars"] )
-    dfr[1, "p"] <- round( 1 - stats::pchisq( dfr[1,"Chisq"], df=dfr[1,"df"] ), digits)
+    dfr[1,'Chisq'] <- dfr[1,'Deviance'] - dfr[2,'Deviance']
+    dfr[1,'df'] <- abs( dfr[1,'Npars'] - dfr[2,'Npars'] )
+    dfr[1,'p'] <- round( 1 - stats::pchisq( dfr[1,'Chisq'], df=dfr[1,'df'] ), digits)
     tam_round_data_frame_print(obji=dfr, from=2, digits=digits, rownames_null=TRUE)
     invisible(dfr)
 }
