@@ -1,5 +1,5 @@
 ## File Name: tam.linking.R
-## File Version: 0.349
+## File Version: 0.368
 
 tam.linking <- function( tamobj_list, type="Hae", method="joint",
     pow_rob_hae=1, eps_rob_hae=1e-4, theta=NULL, wgt=NULL, wgt_sd=2, fix.slope=FALSE,
@@ -18,28 +18,28 @@ tam.linking <- function( tamobj_list, type="Hae", method="joint",
     theta <- matrix( theta, ncol=1)
     #--- extract parameters
     parameters_list <- list()
-    for (mm in 1:NM){
+    for (mm in 1L:NM){
         parameters_list[[mm]] <- tam_linking_extract_parameters(
                                         tamobj=tamobj_list[[mm]],
                                         elim_items=elim_items[[mm]] )
     }
 
     #**** LINKING
-    entries <- c("linking_items", "B", "A", "AXsi", "guess", "M", "SD")
+    entries <- c('linking_items', 'B', 'A', 'AXsi', 'guess', 'M', 'SD')
     linking_list <- list()
     linking_args <- list( theta=theta, wgt=wgt, type=type, fix.slope=fix.slope,
                             pow_rob_hae=pow_rob_hae, eps_rob_hae=eps_rob_hae,
                             par_init=par_init)
 
     #--- subfunction chain linking
-    if (method=="chain"){
+    if (method=='chain'){
         res <- tam_linking_chain( NM=NM, parameters_list=parameters_list,
                     entries=entries, verbose=verbose, linking_args=linking_args,
                     linking_list=linking_list)
     }
 
     #--- subfunction joint linking
-    if (method=="joint"){
+    if (method=='joint'){
         res <- tam_linking_joint(NM=NM, parameters_list=parameters_list,
                     linking_args=linking_args)
     }
@@ -60,6 +60,6 @@ tam.linking <- function( tamobj_list, type="Hae", method="joint",
                     N_common=N_common, theta=theta, wgt=wgt, NS=NM, type=type,
                     method=method, pow_rob_hae=pow_rob_hae, eps_rob_hae=eps_rob_hae,
                     par=par, CALL=CALL,time=time)
-    class(res) <- "tam.linking"
+    class(res) <- 'tam.linking'
     return(res)
 }
