@@ -1,5 +1,5 @@
 ## File Name: tam_linking_extract_parameters_trait_distribution.R
-## File Version: 0.02
+## File Version: 0.039
 
 tam_linking_extract_parameters_trait_distribution <- function(tamobj)
 {
@@ -8,7 +8,7 @@ tam_linking_extract_parameters_trait_distribution <- function(tamobj)
     group <- tamobj$group
     M <- as.vector( unlist(tamobj$beta) )
     variance <- tamobj$variance
-    if ( class_tamobj %in% c("tam.mml", "tam.mml.2pl", "tam.mml.mfr") ){
+    if ( class_tamobj %in% c('tam.mml', 'tam.mml.2pl', 'tam.mml.mfr') ){
         if (G > 1){
             variance_group <- tam_aggregate( variance, group, mean=TRUE)
             SD <- sqrt( variance_group[,2] )
@@ -16,8 +16,15 @@ tam_linking_extract_parameters_trait_distribution <- function(tamobj)
             SD <- sqrt(variance[1,1])
         }
     } else {
-        SD <- sqrt( as.vector( unlist( variance ) ) )
+        if (!is.null(variance)){
+            SD <- sqrt( as.vector( unlist( variance ) ) )
+        } else {
+            SD <- 1
+        }
     }
+    if (is.null(G)){ G <- 1 }
+    if (is.null(M)){ M <- 0 }
+
     #--- output
     res <- list( class_tamobj=class_tamobj, G=G, group=group, M=M, SD=SD)
     return(res)
