@@ -1,12 +1,12 @@
 ## File Name: tamcat.R
-## File Version: 9.06
+## File Version: 9.072
+
 
-######################################################
 tamcat <- function( label, time0, active )
 {
     if (active){
         z0 <- time0
-        cat( label, "  " )
+        cat( label, '  ' )
         z1 <- Sys.time()
         print(z1-z0)
         z0 <- z1
@@ -16,4 +16,3 @@ tamcat <- function( label, time0, active )
     }
     return(zout)
 }
-######################################################
