@@ -1,5 +1,5 @@
 ## File Name: weighted_var.R
-## File Version: 9.12
+## File Version: 9.131
 
 
 # weighted variance
@@ -10,7 +10,7 @@ weighted_var <- function( x, w=rep(1,length(x) ), method="unbiased",
     res <- tam_weighted_stats_select(x=x, w=w, select=select)
     x <- res$x
     w <- res$w
-    dat <- data.frame("x"=x )
+    dat <- data.frame(x=x)
     res <- stats::cov.wt( x=dat, wt=w, cor=FALSE, center=TRUE, method=method )
     res <- res$cov[1,1]
     return(res)
